========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |travis| |readthedocs|
    * - package
      - | |pyver| |commits-since|

.. |pyver| image:: https://img.shields.io/badge/python-3.6+-blue.svg
    :alt: Requires Python 3.6+
    :target: https://www.python.org/getit

.. |travis| image:: https://travis-ci.org/plstcharles/thelper.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/plstcharles/thelper

.. |commits-since| image:: https://img.shields.io/github/commits-since/plstcharles/thelper/latest.svg
    :alt: Commits since latest release
    :target: https://github.com/plstcharles/thelper/compare/v0.2.1...master

.. |readthedocs| image:: https://readthedocs.org/projects/thelper/badge/?version=latest
    :alt: Documentation Build Status
    :target: https://thelper.readthedocs.io/en/latest/?badge=latest

.. not ready for live version (WiP)

   .. |requires| image:: https://requires.io/github/plstcharles/thelper/requirements.svg?branch=master
       :alt: Requirements Status
       :target: https://requires.io/github/plstcharles/thelper/requirements/?branch=master

   .. |version| image:: https://img.shields.io/pypi/v/thelper.svg
       :alt: PyPI Package latest release
       :target: https://pypi.python.org/pypi/thelper

   .. |wheel| image:: https://img.shields.io/pypi/wheel/thelper.svg
       :alt: PyPI Wheel
       :target: https://pypi.python.org/pypi/thelper

   .. |supported-versions| image:: https://img.shields.io/pypi/pyversions/thelper.svg
       :alt: Supported versions
       :target: https://pypi.python.org/pypi/thelper

   .. |supported-implementations| image:: https://img.shields.io/pypi/implementation/thelper.svg
       :alt: Supported implementations
       :target: https://pypi.python.org/pypi/thelper

.. end-badges

This package provides a training framework and CLI for PyTorch-based machine learning projects. This is free software distributed
under the `Apache Software License version 2.0 <https://tldrlegal.com/license/apache-license-2.0-(apache-2.0)>`_ built by researchers
and developers from the Centre de Recherche Informatique de Montréal / Computer Research Institute of Montreal (CRIM).

For installation instructions, refer to the `installation guide <https://github.com/plstcharles/thelper/blob/master/INSTALL.rst>`_. For
usage instructions, refer to the `user guide <https://github.com/plstcharles/thelper/blob/master/thelper_usage.txt>`_. Information about
the auto-generated documentation is available `here <https://github.com/plstcharles/thelper/blob/master/DOCUMENTATION.rst>`_.


Notes
-----

Development is still on-going --- expect the API and the internal classes to change rapidly.

The project's structure was originally generated by `cookiecutter <https://github.com/audreyr/cookiecutter>`_ via `ionelmc's template <https://github.com/ionelmc/cookiecutter-pylibrary>`_.
